slangpy.bindings
==================

The ``slangpy.bindings`` module contains the tools required to extend SlangPy to 
support new Python types. All slangpy's built-in types are implemented using these 
classes (see ``slangpy/builtin``).

API
---

.. automodule:: slangpy.bindings
   :members:
   :imported-members:
   